# Py Collector

Py Collector is a simple, reliable, DB agnostic framework for consistently harvesting data from
any source.

It utilizes two main components, the `Collector` and the `Scheduler`. 

## Code Examples

| Data | Code |
|--- | :---: |
|Collect Weather Data into SQL Alchemy| Test|
|Collect Energy Data into a csv| Test|
|Collect Housing data into Mongo DB| Test|
|Send email with Data| Test|